#include <TinyDHT.h>        // lightweight DHT sensor library
#include <avr/power.h>      // needed to up clock to 16 MHz on 5v Trinket
#include <TinyWireM.h>      // lightweight wire library
#include <Tiny4kOLED.h>     // lightweight oled library
#include "5x5_font.h"       // font library from TinyOLED-fonts

#define DHTTYPE DHT11       // DHT 11 temperature and humidity sensor
#define TEMPTYPE 0          // Use 1 for Fahrenheit and 0 for Celsius
#define DHTPIN 10           // Sensor connected to pin 10 on attiny84
const DCfont *currentFont = FONT5X5;  // set current font here

int ledStrip = 7;          // 12V DC growlight LED strip connected to pwm digital pin 7 through mosfet
int pump = 5;              // 12V DC water pump connected to digital pwm pin 5 through mosfet
int potentiometer1 = 3;    // potentiometer 1 connected to  A3
int potentiometer2 = 2;    // potentiometer 2 connected to  A2
const int lightSensorPin = 1;

DHT dht(DHTPIN, DHTTYPE);  // define Temp Sensor

void setup()
{
pinMode(ledStrip, OUTPUT); // sets the pin as output
pinMode(pump, OUTPUT);     // sets the pin as output
dht.begin();               // Initialize DHT Teperature Sensor
oled.begin();              // Send the initialization sequence to the oled.
oled.setFont(currentFont); // set font to current
oled.clear();             // Clear the memory before turning on the display
oled.on();                // Turn on the display
oled.switchRenderFrame(); // Switch the half of RAM that we are writing to, to be the half that is non currently displayed
}

void loop()
{
analogWrite(ledStrip, analogRead(potentiometer1)/ 4);   // analogRead values go from 0 to 1023, analogWrite values from 0 to 255
analogWrite(pump, analogRead(potentiometer2)/ 4);       // analogRead values go from 0 to 1023, analogWrite values from 0 to 255
int8_t h = dht.readHumidity();                          // read humidity
int16_t t = dht.readTemperature(TEMPTYPE); 
updateDisplay();
delay(50);  

int lightSensorReading = 0;
  lightSensorReading = analogRead(lightSensorPin);
  delay(100);
  if(lightSensorReading < 5){            
    analogWrite(ledStrip, analogRead(lightSensorReading)/24);
  }
  else {
  analogWrite(ledStrip, analogRead(lightSensorReading)/24);
  }
}

void updateDisplay() {
int8_t h = dht.readHumidity();                          // read humidity
int16_t t = dht.readTemperature(TEMPTYPE);              // read temperature
oled.clear();             // Clear the half of memory not currently being displayed.
oled.setCursor(0, 5);     // Position the text cursor
oled.print(F("Temperature: "));   // Write text to oled RAM (which is not currently being displayed).
oled.print(t);
oled.print(" *C");
oled.setCursor(0, 10); 
oled.print(F("Humidity: "));
oled.print(h);
oled.print(" %");
oled.switchFrame();       // Swap half of RAM is being written to, and which half which is being displayed.
}
